==> testsuite-1.0.0-beta1.tar.gz: testsuite/js/testsuite_menu.js <==
(function ($, Drupal) {
    var menuInitialized = false;
    function menuInit() {
        if(!menuInitialized) {
            /* $(".test-suite-area-links").click(function(evt) {
                if($(evt.target.lastChild).hasClass("up")) {
                    $(evt.target.lastChild).removeClass("up");
                    $(evt.target.lastChild).addClass('down');
                    $(evt.target.nextSibling.children).children().css('display', 'none');
                } else {
                    $(evt.target.lastChild).removeClass("down");
                    $(evt.target.lastChild).addClass('up');
                    $(evt.target.nextSibling.children).children().css('display', 'block');
                }
            }); */

            $(".test-suite-module-links").click(function(evt) {
                evt.preventDefault();
                console.log(evt.target);
                if($(evt.target.lastChild).hasClass("up")) {
                    $(evt.target.lastChild).removeClass("up");
                    $(evt.target.lastChild).addClass('down');
                    $(evt.target.nextSibling.children).children().css('display', 'none');
                } else {
                    $(evt.target.lastChild).removeClass("down");
                    $(evt.target.lastChild).addClass('up');
                    $(evt.target.nextSibling.children).children().css('display', 'block');
                }
            });
            menuInitialized = true;
        }
    }

    'use strict';

    Drupal.behaviors.test_suite_menu = {
        attach: function(context, settings) {
            menuInit();
        }
    }
})(jQuery, Drupal);

==> testsuite-1.0.8-beta1.tar.gz: testsuite/js/testsuite_menu.js <==
(function ($, Drupal) {
    var menuInitialized = false;
    function menuInit() {
        if(!menuInitialized) {
            /* $(".test-suite-area-links").click(function(evt) {
                if($(evt.target.lastChild).hasClass("up")) {
                    $(evt.target.lastChild).removeClass("up");
                    $(evt.target.lastChild).addClass('down');
                    $(evt.target.nextSibling.children).children().css('display', 'none');
                } else {
                    $(evt.target.lastChild).removeClass("down");
                    $(evt.target.lastChild).addClass('up');
                    $(evt.target.nextSibling.children).children().css('display', 'block');
                }
            }); */

            $(".test-suite-module-links").click(function(evt) {
                evt.preventDefault();
                console.log(evt.target);
                if($(evt.target.lastChild).hasClass("up")) {
                    $(evt.target.lastChild).removeClass("up");
                    $(evt.target.lastChild).addClass('down');
                    $(evt.target.nextSibling.children).children().css('display', 'none');
                } else {
                    $(evt.target.lastChild).removeClass("down");
                    $(evt.target.lastChild).addClass('up');
                    $(evt.target.nextSibling.children).children().css('display', 'block');
                }
            });
            menuInitialized = true;
        }
    }

    'use strict';

    Drupal.behaviors.testsuite_menu = {
        attach: function(context, settings) {
            menuInit();
        }
    }
})(jQuery, Drupal);
